@@ -1,7 +1,11 @@
 from requests.adapters import HTTPAdapter
 from urllib3.connectionpool import HTTPSConnectionPool, HTTPConnectionPool
 
-from .connector import ModifiedHTTPConnection, ModifiedHTTPSConnection
+from .connector import (
+    ModifiedHTTPConnection,
+    ModifiedHTTPSConnection,
+    set_dns_cache_expire_time
+)
 from .resolver import set_dns_provider
 
 __all__ = ('DNSOverHTTPSAdapter',)
@@ -13,13 +17,18 @@ class DNSOverHTTPSAdapter(HTTPAdapter):
     -----------
     provider: :class:`str`
         A DoH provider
+    cache_expire_time: :class:`float`
+        Set DNS cache expire time
     **kwargs
         These parameters will be passed to :meth:`requests.adapters.HTTPAdapter.__init__()`
     """
-    def __init__(self, provider=None, **kwargs):
+    def __init__(self, provider=None, cache_expire_time=None, **kwargs):
         if provider:
             set_dns_provider(provider)
 
+        if cache_expire_time:
+            set_dns_cache_expire_time(cache_expire_time)
+
         super().__init__(**kwargs)
 
     def get_connection(self, url, proxies=None):
